/*
 * Copyright (c) 2005
 * Telecooperation Office (TecO), Universitaet Karlsruhe (TH), Germany.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 * 3. Neither the name of the Universitaet Karlsruhe (TH) nor the names
 *    of its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written
 *    permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Author(s): Philipp Scholl <scholl@teco.edu>
 */
package edu.teco.particles.pComponent.io;

import java.awt.event.*;
import java.util.*;

import javax.swing.Timer;

import edu.teco.particles.pComponent.io.*;

/**
 * expires a given template.
 * 
 * Functionality: - tests if a given traffic template is still available on the
 * network. - done by using special hlo packets + timeouts.
 * 
 * Throws an Event if the given template isn't available anymore.
 */
public class TemplateExpire implements ActionListener
{
  public static final String EXPIRED_CMD = "Template expired.";

  /**
   * the timeout in milliseconds.
   */
  protected int              _timeout;

  /**
   * the timer object for timeout handling.
   */
  protected Timer            _timer;

  protected ParticleTemplate _template;

  /**
   * creates a new Template Expirer.
   * 
   * @param timeout
   *          the maximum time in milliseconds until the template expires.
   * @param template
   *          the template to expire.
   */
  public TemplateExpire(int timeout, ParticleTemplate template)
  {
    _timeout = timeout;

    _template = template;
    _template.addActionListener(this);

    // the timer resets itself!
    _timer = new Timer(timeout, this);
    _timer.start();
  }

  /**
   * react on the timer expiration. - set the _doneRetries. - if all retries
   * failed, send the EXPIRED_CMD.
   */
  public void actionPerformed(ActionEvent e)
  {
    String command = e.getActionCommand();

    if (command == ParticleTemplate.MATCH_CMD)
    {
      _timer.restart();
    }
    else
    // timer expired
    {
      _notifyActionListeners();
      _timer.stop();
      _listeners.clear();
    }
  }

  /**
   * @name ActionListener. @{
   */
  private LinkedList<ActionListener> _listeners = new LinkedList<ActionListener>();

  public void addActionListener(ActionListener action)
  {
    _listeners.add(action);
  }

  public void removeActionListener(ActionListener action)
  {
    _listeners.remove(action);
  }

  public List<ActionListener> getActionListeners()
  {
    return _listeners;
  }

  protected void _notifyActionListeners()
  {
    ActionEvent event = new ActionEvent(_template, 0, EXPIRED_CMD);
    for (ActionListener listener : _listeners)
    {
      listener.actionPerformed(event);
    }
  }
  /** @} */

}
