/*
 * Copyright (c) 2004
 * Telecooperation Office (TecO), Universitaet Karlsruhe (TH), Germany.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 * 3. Neither the name of the Universitaet Karlsruhe (TH) nor the names
 *    of its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written
 *    permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * @author Philipp Scholl <scholl@teco.edu>
 */

package edu.teco.particles.pComponent.networkMap;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.LinkedList;

import javax.swing.event.TreeModelEvent;
import javax.swing.event.TreeModelListener;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;
import javax.swing.tree.TreeModel;
import javax.swing.tree.TreeNode;
import javax.swing.tree.TreePath;

import edu.teco.particles.libParticle.ParticlePacket;
import edu.teco.particles.libParticle.ParticleTuple;

/**
 * the model for the network map. The tree is two levels deep. It looks like
 * this: all contextes |- srcid1 |- agx |- cts |- sgx:1 |- sgx:2 |- srcid2 |-
 * lop
 * 
 * The model takes complete particlePackets and deduces the srcId and the tuples
 * to be displayed in the tree. Replaced will be every packet containing a
 * different set of tuples with the same srcid. So at any time only one
 * exemplary is being displayed. This might lead to a severe problem when a
 * particles send "alternating" packets.
 */
public class NetworkMapModel extends DefaultTreeModel
{

  /**
   * @param arg0
   */
  public NetworkMapModel()
  {
    super(new DefaultMutableTreeNode("all"));
  }

  // /** a mutex to synchronize access to the particle list */
  // int[] mutex = new int[0];
  //
  // /** holds the root list. Contains ParticlePackets.
  // */
  // protected LinkedList _packetList = new LinkedList();
  //
  // /** returns a standard root.
  // * @see javax.swing.tree.TreeModel#getRoot()
  // */
  // public Object getRoot() {
  // return "all contextes";
  // }
  //
  // /**
  // * @see javax.swing.tree.TreeModel#getChild(java.lang.Object, int)
  // */
  // public Object getChild( Object obj, int index ) {
  // try {
  // Object ret = null;
  //
  // if( obj instanceof String ) {
  // synchronized( mutex ) {
  // ret = _packetList.get( index );
  // }
  // } else if( obj instanceof ParticlePacket ) {
  // // search the right tuple in the packet.
  // ParticlePacket pck = (ParticlePacket) obj;
  // ParticleTuple tuple = pck.firstAcl();
  // int i = 0;
  //
  // while( tuple != null && i != index ) {
  // i++;
  //
  // tuple = pck.nextAcl( tuple );
  // }
  //
  // ret = tuple;
  // } else if( obj instanceof ParticleTuple ) {
  // ret = null;
  // }
  //
  // return ret;
  //
  // } catch( ClassCastException e ) {
  // e.printStackTrace();
  // System.exit( -1 );
  //
  // return null;
  // }
  // }
  //
  // /**
  // * @see javax.swing.tree.TreeModel#getChildCount(java.lang.Object)
  // */
  // public int getChildCount(Object obj) {
  // int count = 0;
  //
  // if( obj instanceof String ) {
  // synchronized( mutex ) {
  // count = _packetList.size();
  // }
  // } else if( obj instanceof ParticlePacket ) {
  // ParticlePacket pck = (ParticlePacket) obj;
  // ParticleTuple tuple = pck.firstAcl();
  //
  // while( tuple != null ) {
  // count++;
  // tuple = pck.nextAcl( tuple );
  // }
  // }
  //
  // return count;
  // }
  //
  // /** tests the obj to see if it is a leaf.
  // * Implementation note:
  // * isLeaf does check if obj is a ParticleTuple OR
  // * ParticlePacket is empty.
  // *
  // * @see javax.swing.tree.TreeModel#isLeaf(java.lang.Object)
  // */
  // public boolean isLeaf(Object obj) {
  // boolean ret = false;
  //
  // if( obj instanceof ParticleTuple ) {
  // ret = true;
  // } else if( obj instanceof ParticlePacket ) {
  // ParticlePacket pck = (ParticlePacket) obj;
  // try {
  // pck.firstAcl();
  // } catch( IllegalArgumentException e ) {
  // ret = true;
  // }
  // }
  //
  // return false;
  // }
  //
  // /**
  // * @see
  // javax.swing.tree.TreeModel#valueForPathChanged(javax.swing.tree.TreePath,
  // java.lang.Object)
  // */
  // public void valueForPathChanged(TreePath arg0, Object arg1) {
  // assert( false ) : "not implemented";
  // }
  //
  // /**
  // * @see javax.swing.tree.TreeModel#getIndexOfChild(java.lang.Object,
  // java.lang.Object)
  // */
  // public int getIndexOfChild(Object parent, Object child) {
  // for (int count = getChildCount(parent), i = 0; i < count; i++)
  // if (getChild(parent, i).equals(child))
  // return i;
  //
  // return -1;
  // }
  //
  // /** adds a packet to the tree model.
  // * This is done asynchrounsly so we will be synchronizing on a mutex.
  // * We will first look if a packet from the same srcId is in the list and
  // * if so remove it, prior to adding the new pck.
  // */
  // public void add( ParticlePacket new_pck ) {
  // synchronized( mutex ) {
  // if( _packetList.isEmpty() ) {
  // _packetList.addFirst( new_pck );
  //
  // Object[] path = { getRoot(), new_pck };
  // Object[] child = { new_pck };
  //
  // fireTreeNodesInserted( getRoot(), path, new int[]{ 0 }, child );
  // }
  //
  // for( Iterator i = _packetList.iterator(); i.hasNext(); ) {
  // ParticlePacket old_pck = (ParticlePacket) i.next();
  //
  // // if( old_pck.equals( new_pck ) ) {
  // // System.out.println( old_pck);
  // // return; // do nothing
  // // } else if( old_pck.getSrcId().equals( new_pck.getSrcId() ) ) {
  // // i.remove(); // remove the old packet
  // //
  // // _packetList.addFirst( new_pck );
  // //
  // // Object[] path = { getRoot(), new_pck };
  // // Object[] child = { new_pck };
  // //
  // // fireTreeNodesInserted( getRoot(), path, new int[]{ 0 }, child );
  // //
  // // // we can stop here
  // // return;
  // // }
  // }
  // }
  // }
}
