/**
  * Copyright (C) 2004-2005 Till Riedel. All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
  * 1. Redistributions of source code must retain the above copyright
  *    notice, this list of conditions and the following disclaimer.
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
  * 
  * THIS SOFTWARE IS PROVIDED BY AUTHOR AND CONTRIBUTORS ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  * ARE DISCLAIMED.  IN NO EVENT SHALL AUTHOR OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
  * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
  * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
  * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
 **/

#include <sys/types.h>
#include <stdio.h>
#include <stddef.h>
#include <string.h>
#include <stdlib.h>
#include <unistd.h>
#include <assert.h>


void print_pdebug(char *data, uint8_t len)
{
  struct info
  {
    uint8_t event:8;
    uint32_t pointer:24;
    uint8_t data[];
  } *info ;

  uint8_t data_len;


  info = (struct info *) data;

  data_len=len-4;
  assert(offsetof(struct info,data)==4);

  printf("\n%p:",(void *)info->pointer);

  switch(info->event)
  {
    case 'a': printf("assertion: failed\n" );exit(1);break;
    case 'c': printf("trace:" );break;
    case 'l': printf("long:\t%u",*((uint16_t *)info->data));break;
    case 's': printf("string:\t" );
              if(data_len)
              {
                int i;
                putchar('"');
                for (i = 0; i < data_len; i++) putchar(info->data[i]); 
                putchar('"');
              }
              break;
    case 'r': printf("return:\t");
              if(data_len)
              {
                int i=data_len;
                printf(" (int%d_t)\t0x",data_len*8);
                while(i--) printf("%02x",(unsigned char)info->data[i]);
              }
              break;
    case 'v': printf("var:\t");
              if(data_len)
              {
                int i=data_len;
                printf(" (int%d_t)\t0x",data_len*8);
                while(i--) printf("%02x",(unsigned char)info->data[i]);
              }
              break;
    default:
              printf("unknown event 0x%x",info->event);
              break;
  }
fflush(stdout);
}
