/*
 * Copyright (c) 2004
 * Telecooperation Office (TecO), Universitaet Karlsruhe (TH), Germany.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 * 3. Neither the name of the Universitaet Karlsruhe (TH) nor the names
 *    of its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written
 *    permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * @author Philipp Scholl <scholl@teco.edu>
 */

package edu.teco.particles.pComponent.scanner;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;
import javax.swing.JTree;

import edu.teco.particles.libParticle.ParticleSrcId;
import edu.teco.particles.libParticle.ParticleTuple;

/**
 * Action to add a SrcID to a tree.
 */
public class AddSrcIdAction extends AbstractAction
{

  protected JTree         _tree;

  protected static String lastAnswer;

  public AddSrcIdAction(JTree tree)
  {
    super();
    _tree = tree;
  }

  public void actionPerformed(ActionEvent arg0)
  {
    String answer = (String) JOptionPane.showInputDialog("enter new srcId",
        lastAnswer);
    lastAnswer = answer;

    ParticleSrcId srcId;
    ContextTreeModel model;

    try
    {
      if (answer != null)
      {
        srcId = new ParticleSrcId(answer);

        model = (ContextTreeModel) _tree.getModel();
        model.add(srcId, new ParticleTuple("add"));
        _tree.updateUI();
      }
    }
    catch (IllegalArgumentException e)
    {
      JOptionPane.showMessageDialog(_tree, "srcId must be in dotted format. "
          + "like \"127.0.0.1.127.0.0.1\"");
    }
  }

  public Object getValue(String key)
  {
    super.getValue(key);

    if (key.equals(SHORT_DESCRIPTION))
    {
      return "add Source ID ...";
    }
    else if (key.equals(NAME))
    {
      return "add Source ID ...";
    }

    return null;
  }

}
