/*
 * Copyright (c) 2004
 * Telecooperation Office (TecO), Universitaet Karlsruhe (TH), Germany.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 * 3. Neither the name of the Universitaet Karlsruhe (TH) nor the names
 *    of its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written
 *    permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * @author Philipp Scholl <scholl@teco.edu>
 */

package edu.teco.particles.pComponent.scanner;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTree;
import javax.swing.UIManager;
import javax.swing.tree.TreeCellRenderer;

import edu.teco.particles.libParticle.ParticleSrcId;
import edu.teco.particles.libParticle.ParticleTuple;
import edu.teco.particles.pComponent.util.ParticleContext;

/**
 * Renders the TreeNodes.
 */
public class ParticleNodeRenderer implements TreeCellRenderer
{
  protected JPanel colorPanel;

  /*
   * (non-Javadoc)
   * 
   * @see javax.swing.tree.TreeCellRenderer#getTreeCellRendererComponent(javax.swing.JTree,
   *      java.lang.Object, boolean, boolean, boolean, int, boolean)
   */
  public Component getTreeCellRendererComponent(final JTree tree, Object value,
      boolean selected, boolean expanded, boolean isLeaf, int row,
      boolean hasFocus)
  {
    JComponent renderer = null;
    JLabel label = new JLabel();

    if (value instanceof ParticleSrcId)
    {
      ParticleSrcId id = (ParticleSrcId) value;
      label.setText(id.toString());
      renderer = label;
    }
    else if (value instanceof ParticleContext)
    {
      ParticleContext ctx = (ParticleContext) value;
      ParticleTuple tuple = ((ParticleContext) value).getTuple();
      label.setText(tuple.getAclType());

      JPanel panel = new JPanel();
      BorderLayout layout = new BorderLayout();
      layout.setHgap(10);
      panel.setLayout(layout);
      panel.add(label, BorderLayout.CENTER);

      final JPanel colorPanel = new JPanel();
      colorPanel.setBackground(((ParticleContext) value).getColor());
      panel.add(colorPanel, BorderLayout.WEST);
      colorPanel.setPreferredSize(new Dimension(30, 12));

      ctx.addPropertyChangeListener(new PropertyChangeListener() {
        public void propertyChange(PropertyChangeEvent e)
        {
          if (e.getPropertyName().equals(ParticleContext.COLOR))
          {
            colorPanel.setBackground((Color) e.getNewValue());
            colorPanel.setOpaque(true);
            tree.updateUI();
          }
        }
      });
      renderer = panel;
      panel.setOpaque(false);

    }
    else
    {
      label.setText(value.toString());
      renderer = label;
    }

    if (selected)
    {
      label.setBackground(UIManager.getColor("Tree.selectionBackground"));
      label.setForeground(UIManager.getColor("Tree.selectionForeground"));
      label.setOpaque(true);
    }

    return renderer;
  }

}
