/*
 * Created on 03.05.2005
 *
 * Copyright (c) 2004
 * Telecooperation Office (TecO), Universitaet Karlsruhe (TH), Germany.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 * 3. Neither the name of the Universitaet Karlsruhe (TH) nor the names
 *    of its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written
 *    permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

package edu.teco.particles.pComponent.sender;

import java.text.ParseException;
import java.util.LinkedList;

import edu.teco.particles.libParticle.ParticleTuple;

/**
 * Support for changig a ParticleTuple.
 */
public class ProxyParticleTuple
{
  protected String _type = null;

  protected LinkedList<Short> _data = new LinkedList<Short>();

  protected final static String STRING_SEPERATOR = " ";
  
  protected boolean isValid = false; 

  public ProxyParticleTuple(ParticleTuple tuple)
  {
    setType(tuple.getAclType());
    try
    {
      setData(tuple.toString());
    }
    catch (ParseException e)
    {
      // ignore
    }
  }

  public ProxyParticleTuple()
  {
  }

  public void setType(String type)
  {
    _type = type;
    setValid(true);
  }

  /**
   * sets the data of the tuple.
   * 
   * @param str
   *          data getrennt by spaces
   */
  public void setData(String str) throws ParseException
  {
    _data.clear();
    String[] nums = str.split(STRING_SEPERATOR);

    for (String num : nums)
    {
      if (num.length() != 0)
      {
        Short val = Short.parseShort(num);
        if (val < 0 || val > 255)
        {
          setValid(false);
          throw new ParseException("value is out of valid range", 0);
        }
        else
        {
          setValid(true);
          _data.add(val);
        }
      }
    }
  }

  public ParticleTuple getTuple()
  {
    short[] data = new short[_data.size()];

    for (int i = 0; i < _data.size(); i++)
    {
      data[i] = _data.get(i).shortValue();
    }

    if (_type != null)
    {
      return new ParticleTuple(_type, data);
    }
    else
    {
      return new ParticleTuple("def");
    }
  }

  public boolean isValid()
  {
    return isValid;
  }

  public void setValid(boolean isValid)
  {
    this.isValid = isValid;
  }

  public String getType()
  {
    return _type;
  }

  public String getData()
  {
    String str = "";
    for (Short datum : _data)
    {
      str += datum.toString();
      str += " ";
    }
      
    return str;
  }
}
