/*
 * Created on 13.12.2004
 *
 * Copyright (c) 2004
 * Telecooperation Office (TecO), Universitaet Karlsruhe (TH), Germany.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 * 3. Neither the name of the Universitaet Karlsruhe (TH) nor the names
 *    of its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written
 *    permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */
package edu.teco.particles.pComponent.util;

import javax.swing.JButton;
import javax.swing.JPanel;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Collection;
import java.util.Iterator;

/**
 * @author scholl@teco.edu
 * 
 * Builder for the Commands GUI
 */

public class CommandsGUI extends JPanel implements ActionListener
{

  /**
   * 
   * @uml.property name="command"
   * @uml.associationEnd multiplicity="(1 -1)" aggregation="aggregate"
   *                     elementType="edu.teco.particles.pComponent.frameWork.Command"
   */
  private Collection commands;

  /**
   * creates a new Commands GUI and adds all commands.
   * 
   * @param commands
   *          the Commands to add to the GUI
   */
  public CommandsGUI(Collection commands)
  {
    this.commands = commands;

    Iterator it = commands.iterator();
    while (it.hasNext())
    {
      Command com = (Command) it.next();
      JButton comGui = new JButton(com.getName());
      this.add(comGui);
      comGui.addActionListener(this);
      comGui.setActionCommand(com.getName());
    }
  }

  /**
   * checks the ActionCommand to equal the name of some Command, and if found
   * calls execute() on the Command.
   * 
   * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
   */
  public void actionPerformed(ActionEvent e)
  {
    Iterator it = commands.iterator();
    while (it.hasNext())
    {
      Command com = (Command) it.next();
      if (com.getName().equals(e.getActionCommand()))
      {
        com.execute();
      }
    }
  }
}
